@@ -1,25 +1,11 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "richtextcomposeractions.h"
 #include "richtextcomposercontroler.h"
-#include "richtextcomposer.h"
 #include "emoticon/emoticontexteditaction.h"
 #include "tableactionmenu.h"
 #include <KToggleAction>
@@ -42,7 +28,7 @@ public:
 
     QVector<QAction *> richTextActionList;
 
-    KPIMTextEdit::RichTextComposerControler *composerControler = nullptr;
+    KPIMTextEdit::RichTextComposerControler *const composerControler;
     KToggleAction *action_align_left = nullptr;
     KToggleAction *action_align_right = nullptr;
     KToggleAction *action_align_center = nullptr;
@@ -159,7 +145,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
         ac->addAction(QStringLiteral("format_align_justify"), d->action_align_justify);
     }
 
-    QActionGroup *alignmentGroup = new QActionGroup(this);
+    auto *alignmentGroup = new QActionGroup(this);
     alignmentGroup->addAction(d->action_align_left);
     alignmentGroup->addAction(d->action_align_center);
     alignmentGroup->addAction(d->action_align_right);
@@ -188,7 +174,7 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
         ac->addAction(QStringLiteral("direction_rtl"), d->action_direction_rtl);
     }
 
-    QActionGroup *directionGroup = new QActionGroup(this);
+    auto *directionGroup = new QActionGroup(this);
     directionGroup->addAction(d->action_direction_ltr);
     directionGroup->addAction(d->action_direction_rtl);
 
